package com.ruoyi.sim.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.sim.domain.AddOnUser;
import com.ruoyi.sim.service.IAddOnUserService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 用户附加Controller
 *
 * @author tom
 * @date 2024-12-11
 */
@RestController
@RequestMapping("/sim/add_on_user")
public class AddOnUserController extends BaseController {
    @Autowired
    private IAddOnUserService addOnUserService;

    /**
     * 查询用户附加列表
     */
    @PreAuthorize("@ss.hasPermi('sim:add_on_user:list')")
    @GetMapping("/list")
    public TableDataInfo list(AddOnUser addOnUser) {
        startPage();
        List<AddOnUser> list = addOnUserService.selectAddOnUserList(addOnUser);
        return getDataTable(list);
    }

    /**
     * 导出用户附加列表
     */
    @PreAuthorize("@ss.hasPermi('sim:add_on_user:export')")
    @Log(title = "用户附加", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AddOnUser addOnUser) {
        List<AddOnUser> list = addOnUserService.selectAddOnUserList(addOnUser);
        ExcelUtil<AddOnUser> util = new ExcelUtil<AddOnUser>(AddOnUser.class);
        util.exportExcel(response, list, "用户附加数据");
    }

    /**
     * 获取用户附加详细信息
     */
    @PreAuthorize("@ss.hasPermi('sim:add_on_user:query')")
    @GetMapping(value = "/{userId}")
    public AjaxResult getInfo(@PathVariable("userId") Long userId) {
        return success(addOnUserService.selectAddOnUserByUserId(userId));
    }

    /**
     * 新增用户附加
     */
    @PreAuthorize("@ss.hasPermi('sim:add_on_user:add')")
    @Log(title = "用户附加", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody AddOnUser addOnUser) {
        return toAjax(addOnUserService.insertAddOnUser(addOnUser));
    }

    /**
     * 修改用户附加
     */
    @PreAuthorize("@ss.hasPermi('sim:add_on_user:edit')")
    @Log(title = "用户附加", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody AddOnUser addOnUser) {
        return toAjax(addOnUserService.updateAddOnUser(addOnUser));
    }

    /**
     * 删除用户附加
     */
    @PreAuthorize("@ss.hasPermi('sim:add_on_user:remove')")
    @Log(title = "用户附加", businessType = BusinessType.DELETE)
    @DeleteMapping("/{userIds}")
    public AjaxResult remove(@PathVariable Long[] userIds) {
        return toAjax(addOnUserService.deleteAddOnUserByUserIds(userIds));
    }
}
