package com.ruoyi.sim.service.impl;

import java.util.List;

import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.sim.mapper.AddOnUserMapper;
import com.ruoyi.sim.domain.AddOnUser;
import com.ruoyi.sim.service.IAddOnUserService;

/**
 * 用户附加Service业务层处理
 *
 * @author tom
 * @date 2024-12-11
 */
@Service
public class AddOnUserServiceImpl implements IAddOnUserService {
    @Autowired
    private AddOnUserMapper addOnUserMapper;

    /**
     * 查询用户附加
     *
     * @param userId 用户附加主键
     * @return 用户附加
     */
    @Override
    public AddOnUser selectAddOnUserByUserId(Long userId) {
        return addOnUserMapper.selectAddOnUserByUserId(userId);
    }

    /**
     * 查询用户附加列表
     *
     * @param addOnUser 用户附加
     * @return 用户附加
     */
    @Override
    public List<AddOnUser> selectAddOnUserList(AddOnUser addOnUser) {
        return addOnUserMapper.selectAddOnUserList(addOnUser);
    }

    /**
     * 新增用户附加
     *
     * @param addOnUser 用户附加
     * @return 结果
     */
    @Override
    public int insertAddOnUser(AddOnUser addOnUser) {
        addOnUser.setCreateTime(DateUtils.getNowDate());
        return addOnUserMapper.insertAddOnUser(addOnUser);
    }

    /**
     * 修改用户附加
     *
     * @param addOnUser 用户附加
     * @return 结果
     */
    @Override
    public int updateAddOnUser(AddOnUser addOnUser) {
        addOnUser.setUpdateTime(DateUtils.getNowDate());
        return addOnUserMapper.updateAddOnUser(addOnUser);
    }

    /**
     * 批量删除用户附加
     *
     * @param userIds 需要删除的用户附加主键
     * @return 结果
     */
    @Override
    public int deleteAddOnUserByUserIds(Long[] userIds) {
        return addOnUserMapper.deleteAddOnUserByUserIds(userIds);
    }

    /**
     * 删除用户附加信息
     *
     * @param userId 用户附加主键
     * @return 结果
     */
    @Override
    public int deleteAddOnUserByUserId(Long userId) {
        return addOnUserMapper.deleteAddOnUserByUserId(userId);
    }
}
