package com.ruoyi.sim.service.impl;

import java.util.List;

import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.sim.mapper.SimMsgMapper;
import com.ruoyi.sim.domain.SimMsg;
import com.ruoyi.sim.service.ISimMsgService;

/**
 * 模拟器报文Service业务层处理
 *
 * @author tom
 * @date 2024-12-11
 */
@Service
public class SimMsgServiceImpl implements ISimMsgService {
    @Autowired
    private SimMsgMapper simMsgMapper;

    /**
     * 查询模拟器报文
     *
     * @param simMsgId 模拟器报文主键
     * @return 模拟器报文
     */
    @Override
    public SimMsg selectSimMsgBySimMsgId(Long simMsgId) {
        return simMsgMapper.selectSimMsgBySimMsgId(simMsgId);
    }

    /**
     * 查询模拟器报文列表
     *
     * @param simMsg 模拟器报文
     * @return 模拟器报文
     */
    @Override
    public List<SimMsg> selectSimMsgList(SimMsg simMsg) {
        return simMsgMapper.selectSimMsgList(simMsg);
    }

    /**
     * 新增模拟器报文
     *
     * @param simMsg 模拟器报文
     * @return 结果
     */
    @Override
    public int insertSimMsg(SimMsg simMsg) {
        simMsg.setCreateTime(DateUtils.getNowDate());
        return simMsgMapper.insertSimMsg(simMsg);
    }

    /**
     * 修改模拟器报文
     *
     * @param simMsg 模拟器报文
     * @return 结果
     */
    @Override
    public int updateSimMsg(SimMsg simMsg) {
        simMsg.setUpdateTime(DateUtils.getNowDate());
        return simMsgMapper.updateSimMsg(simMsg);
    }

    /**
     * 批量删除模拟器报文
     *
     * @param simMsgIds 需要删除的模拟器报文主键
     * @return 结果
     */
    @Override
    public int deleteSimMsgBySimMsgIds(Long[] simMsgIds) {
        return simMsgMapper.deleteSimMsgBySimMsgIds(simMsgIds);
    }

    /**
     * 删除模拟器报文信息
     *
     * @param simMsgId 模拟器报文主键
     * @return 结果
     */
    @Override
    public int deleteSimMsgBySimMsgId(Long simMsgId) {
        return simMsgMapper.deleteSimMsgBySimMsgId(simMsgId);
    }
}
