package com.ruoyi.sim.service.impl;

import java.util.List;

import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.sim.mapper.SimMapper;
import com.ruoyi.sim.domain.Sim;
import com.ruoyi.sim.service.ISimService;

/**
 * 模拟器Service业务层处理
 *
 * @author tom
 * @date 2024-12-11
 */
@Service
public class SimServiceImpl implements ISimService {
    @Autowired
    private SimMapper simMapper;

    /**
     * 查询模拟器
     *
     * @param simId 模拟器主键
     * @return 模拟器
     */
    @Override
    public Sim selectSimBySimId(Long simId) {
        return simMapper.selectSimBySimId(simId);
    }

    /**
     * 查询模拟器列表
     *
     * @param sim 模拟器
     * @return 模拟器
     */
    @Override
    public List<Sim> selectSimList(Sim sim) {
        return simMapper.selectSimList(sim);
    }

    /**
     * 新增模拟器
     *
     * @param sim 模拟器
     * @return 结果
     */
    @Override
    public int insertSim(Sim sim) {
        sim.setCreateTime(DateUtils.getNowDate());
        return simMapper.insertSim(sim);
    }

    /**
     * 修改模拟器
     *
     * @param sim 模拟器
     * @return 结果
     */
    @Override
    public int updateSim(Sim sim) {
        sim.setUpdateTime(DateUtils.getNowDate());
        return simMapper.updateSim(sim);
    }

    /**
     * 批量删除模拟器
     *
     * @param simIds 需要删除的模拟器主键
     * @return 结果
     */
    @Override
    public int deleteSimBySimIds(Long[] simIds) {
        return simMapper.deleteSimBySimIds(simIds);
    }

    /**
     * 删除模拟器信息
     *
     * @param simId 模拟器主键
     * @return 结果
     */
    @Override
    public int deleteSimBySimId(Long simId) {
        return simMapper.deleteSimBySimId(simId);
    }
}
