package com.ruoyi.sim.service.impl;

import java.util.List;

import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.sim.mapper.TaskFaultMapper;
import com.ruoyi.sim.domain.TaskFault;
import com.ruoyi.sim.service.ITaskFaultService;

/**
 * 任务故障关联Service业务层处理
 *
 * @author tom
 * @date 2024-12-13
 */
@Service
public class TaskFaultServiceImpl implements ITaskFaultService {
    @Autowired
    private TaskFaultMapper taskFaultMapper;

    /**
     * 查询任务故障关联
     *
     * @param relId 任务故障关联主键
     * @return 任务故障关联
     */
    @Override
    public TaskFault selectTaskFaultByRelId(Long relId) {
        return taskFaultMapper.selectTaskFaultByRelId(relId);
    }

    /**
     * 查询任务故障关联列表
     *
     * @param taskFault 任务故障关联
     * @return 任务故障关联
     */
    @Override
    public List<TaskFault> selectTaskFaultList(TaskFault taskFault) {
        return taskFaultMapper.selectTaskFaultList(taskFault);
    }

    /**
     * 新增任务故障关联
     *
     * @param taskFault 任务故障关联
     * @return 结果
     */
    @Override
    public int insertTaskFault(TaskFault taskFault) {
        return taskFaultMapper.insertTaskFault(taskFault);
    }

    /**
     * 修改任务故障关联
     *
     * @param taskFault 任务故障关联
     * @return 结果
     */
    @Override
    public int updateTaskFault(TaskFault taskFault) {
        taskFault.setUpdateTime(DateUtils.getNowDate());
        return taskFaultMapper.updateTaskFault(taskFault);
    }

    /**
     * 批量删除任务故障关联
     *
     * @param relIds 需要删除的任务故障关联主键
     * @return 结果
     */
    @Override
    public int deleteTaskFaultByRelIds(Long[] relIds) {
        return taskFaultMapper.deleteTaskFaultByRelIds(relIds);
    }

    /**
     * 删除任务故障关联信息
     *
     * @param relId 任务故障关联主键
     * @return 结果
     */
    @Override
    public int deleteTaskFaultByRelId(Long relId) {
        return taskFaultMapper.deleteTaskFaultByRelId(relId);
    }
}
