package com.ruoyi.sim.service.impl;

import java.util.List;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.sim.domain.Fault;
import com.ruoyi.sim.domain.vo.FaultTree;
import com.ruoyi.sim.service.IFaultService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.sim.mapper.TaskMapper;
import com.ruoyi.sim.domain.Task;
import com.ruoyi.sim.service.ITaskService;

/**
 * 任务Service业务层处理
 *
 * @author tom
 * @date 2024-12-13
 */
@Service
public class TaskServiceImpl implements ITaskService {
    @Autowired
    private TaskMapper taskMapper;

    /**
     * 查询任务
     *
     * @param taskId 任务主键
     * @return 任务
     */
    @Override
    public Task selectTaskByTaskId(Long taskId) {
        return taskMapper.selectTaskByTaskId(taskId);
    }

    /**
     * 查询任务列表
     *
     * @param task 任务
     * @return 任务
     */
    @Override
    public List<Task> selectTaskList(Task task) {
        return taskMapper.selectTaskList(task);
    }

    /**
     * 新增任务
     *
     * @param task 任务
     * @return 结果
     */
    @Override
    public int insertTask(Task task) {
        task.setCreateTime(DateUtils.getNowDate());
        return taskMapper.insertTask(task);
    }

    /**
     * 修改任务
     *
     * @param task 任务
     * @return 结果
     */
    @Override
    public int updateTask(Task task) {
        task.setUpdateTime(DateUtils.getNowDate());
        return taskMapper.updateTask(task);
    }

    /**
     * 批量删除任务
     *
     * @param taskIds 需要删除的任务主键
     * @return 结果
     */
    @Override
    public int deleteTaskByTaskIds(Long[] taskIds) {
        return taskMapper.deleteTaskByTaskIds(taskIds);
    }

    /**
     * 删除任务信息
     *
     * @param taskId 任务主键
     * @return 结果
     */
    @Override
    public int deleteTaskByTaskId(Long taskId) {
        return taskMapper.deleteTaskByTaskId(taskId);
    }

    // -------------------------------- tom add  --------------------------------
    @Autowired
    private IFaultService faultService;

    /**
     * 为了新建，返回一个带tree结构的数据对象。
     *
     * @return 任务
     */
    public Task selectNewTaskViaSimType(String simType) {
        // check

        //
        Task t = new Task();
        // fa 构建用于查询的对象。
        Fault fa = new Fault();
        fa.setSimType(simType);
        //
        List<FaultTree> ftList = faultService.selectFaultListAllTree(fa);
        t.setTaskId(Task.EMPTY_TASK_ID);
        t.setFaultTreeList(ftList);
        return t;
    }
}
